
#ifndef LTC1298_HEADER
#define LTC1298_HEADER


#define LTC1298_RESOLUTION	4096
#define LTC1298_ZERO_VALUE	0
#define LTC1298_USED_REFERENCE	2.5	//Volt
#define LTC1298_REFERENCE_VALUE	2039



#define CALIB_VALUE_ZEROVOLT	0
#define CALIB_VALUE_REFERENCE_VOLT


#define ADC_LTC1298_CS_SHDN_PORT	PORTB
#define ADC_LTC1298_CLK_PORT		PORTC
#define ADC_LTC1298_DIN_PORT		PORTD
#define ADC_LTC1298_DOUT_PINX		PINC	//IN

#define ADC_LTC1298_SHDN_BIT	0b010000 // AN PortB //PB4
#define ADC_LTC1298_DOUT_BIT	0b010000	//AN PortC	PC4
#define ADC_LTC1298_CLK_BIT	0b100000	//AN PortC	PC5
#define ADC_LTC1298_DIN_BIT	0b10000000	// Verunden = DIN PORTD   PD7



#define ADC_LTC1298_PC_MSK	0b00100000	//AN PortC
#define ADC_LTC1298_PD_MSK	0b10000000	//AN PortD

#define SET_ADC_LTC1298_SHDN() (ADC_LTC1298_CS_SHDN_PORT |= ADC_LTC1298_SHDN_BIT)
#define CLR_ADC_LTC1298_SHDN() (ADC_LTC1298_CS_SHDN_PORT &= ~ADC_LTC1298_SHDN_BIT)

#define SET_ADC_LTC1298_CLK() (ADC_LTC1298_CLK_PORT |= ADC_LTC1298_CLK_BIT)
#define CLR_ADC_LTC1298_CLK() (ADC_LTC1298_CLK_PORT &= ~ADC_LTC1298_CLK_BIT)

#define SET_ADC_LTC1298_DIN() (ADC_LTC1298_DIN_PORT|= ADC_LTC1298_DIN_BIT)
#define CLR_ADC_LTC1298_DIN() (ADC_LTC1298_DIN_PORT &= ~ADC_LTC1298_DIN_BIT)

#define READ_ADC_LTC1298_DOUT()  (ADC_LTC1298_DOUT_PINX & ADC_LTC1298_DOUT_BIT)

//#define ADC_LTC1298_STARTBIT_MSB	0x09	//1001 Directon MSB_LSB mit MSB First
#define ADC_LTC1298_CH1_ONLY		0x0D	//1101
#define ADC_LTC1298_CH2_ONLY		0x0F	//1111
#define ADC_LTC1298_DIFF_PM		0x09	//1001 PlusMinus
#define ADC_LTC1298_DIF_MP			0x0B	//1011 MinusPLUS

#define DELAY_1US				1

// RINGBUFFER - STARRE VERSION
#define RINGBUF_SIZE_MAX 255

/*
1. Schritt, Eingang auf Masse Legen
2. Messen des ADC Wertes bei 0V						-->  ADC_ZeroVAlue
3. Schritt, Eingang auf Reference legen.			--> ReferenceVoltage
4. Messen des ADC Wertes mit Referenzspannung	--> ADC_ReferenceValue

Berechnen Volt/Bit -> >>  ReferenceVoltage/(ADC_ReferenceValue - ADC_ZeroVAlue ) 
*/


typedef struct ADC_CALCULATE
{
float fReferenceVoltage;
uint16_t ui16Calib_Zero_Val;
uint16_t ui16Calib_Reference_Val;
float fVoltProBit;
}ADC_CALCULATE_TYPE;
//Export Prototypen

extern void  Init_LTC1298_Values(void);
extern void ADC_CalculateFaktor(ADC_CALCULATE_TYPE * psADC );
extern uint16_t ADC_12Bit_LTC1298( uint8_t u8Din );
extern float CalcLVolt_LTC1298( uint16_t u16ReadedVal );
extern void Check_LTC1298_Orders(char *pcSmd, float *pfValue1);
extern void InsertInRingBuf( uint16_t u16Val);
extern uint16_t GetRingBufVal( void );

extern uint16_t gau16ADC_RingBuf[RINGBUF_SIZE_MAX];
extern uint16_t * gpu16RingBuf_Parser;
extern uint16_t * gpu16RingBuf_Tail;

#endif //LTC1298_HEADER


